@@ -226,10 +226,11 @@ class Audiences(object):
     allowed_field_types = DEFAULT_ALLOWED_FIELD_TYPES
 
     def __init__(self,
-                 au_domain=None):
+                 au_domain=None,
+                 force_db_init=False):
 
         self.au_domain = au_domain or '_global'
-        self.queries = self.get_queries()
+        self.queries = self.get_queries(force_db=force_db_init)
 
     def add(self,
             query,
