@@ -81,8 +81,8 @@ class Event(object):
     def delete(self, pipe=None):
         if pipe:
             pipe.hdel(self.processing_queue_key,
-                                   self.try_count_key,
-                                   self.result_key)
+                      self.try_count_key,
+                      self.result_key)
         else:
             self.redis_client.hdel(self.processing_queue_key,
                                    self.try_count_key,
@@ -433,10 +433,11 @@ class ProcessingQueue(object):
 
         result = self.redis_client.hgetall(self.queue_key)
         if len(result) > 0:
-            result_dict = {k.decode() if isinstance(k, bytes) else k: v
-                           for k, v in dict(zip(result[::2], result[1::2])).items()}
+            result_dict = {k.decode() if isinstance(k, bytes) else k: v for k, v in result.items()}
             event_dict = {k: v for k, v in result_dict.items() if k.startswith(HASH_EVENT_PREFIX + ':')}
-            self.events = [Event.from_redis_string(raw_string=raw_string, redis_client=self.redis_client)
+            self.events = [Event.from_redis_string(raw_string=raw_string,
+                                                   redis_client=self.redis_client,
+                                                   processing_queue_key=self.queue_key)
                            for raw_string in event_dict.values()]
         else:
             self.events = []
