@@ -33,13 +33,21 @@ def search_obj_from_array(array, fieldname, fieldvalue):
 
 class Timer(object):
 
-    def __init__(self, info=None, logger=None, logger_name='timings'):
+    def __init__(self, name=None, info=None, logger=None, logger_name='timings', sub=False):
 
         self.start = time.time()
         self.end = None
         self.timings = []
         self.info = info
         self.logger = logger or logging.getLogger(logger_name)
+        self.sub = sub
+        self.name = name or 'timer'
+
+    def subtimer(self, name, info=None):
+        t = Timer(name=name, info=info, logger=self.logger, sub=True)
+        self.timings.append(t)
+        return t
+
 
     def register(self, name, info=None):
 
@@ -51,7 +59,7 @@ class Timer(object):
     def done(self, send_log=True, loglvl='info', logverbose=True):
 
         self.end = time.time()
-        self.timings = sorted(self.timings, key=lambda x: x[0])
+        self.timings = sorted(self.timings, key=lambda x: x.start if isinstance(x, Timer) else x[0])
 
         if send_log and not self.logger is None:
             getattr(self.logger, loglvl)('Timing done', extra=self.result(verbose=logverbose))
@@ -61,25 +69,29 @@ class Timer(object):
         if self.end is None:
             self.done(send_log=False)
 
+        durations = [x[1]-x[0] for x in zip([self.start, *self.timings[:-1]], self.timings)]
+
         if verbose:
+
             timings = [{
                 'name': x[1],
                 'time': pytz.utc.localize(datetime.datetime.utcfromtimestamp(x[0])).isoformat(),
                 'info': x[2],
-                'duration': x[0] - self.start
-            } for x in self.timings]
+                'duration': duration
+            } for x, duration in zip(self.timings, durations)]
+
             r = {
                 'start': pytz.utc.localize(datetime.datetime.utcfromtimestamp(self.start)).isoformat(),
                 'end': pytz.utc.localize(datetime.datetime.utcfromtimestamp(self.end)).isoformat(),
                 'duration': self.total,
                 'info': self.info,
-                'timings': timings
-            }
+                'timings': timings}
+
         else:
 
             r = {
-                x[1]: x[0] - self.start
-                for x in self.timings}
+                x[1]: duration
+                for x, duration in zip(self.timings, durations)}
             r.update({'total': self.total})
 
         return r
